##  Creating an Automation by Copying an Existing Automation
You can copy an existing automation, which enables you to create another automation with similar configuration parameters without having to configure them from scratch.
To copy an automation, on the Automations page, hover over an automation, then click the copy button that appears.
When you copy an automation, the copy is created in draft state. Before you activate the copied automation, edit the configuration parameters to ensure that you don't have two duplicate automations.
